@@ -3,7 +3,7 @@ package Config::Properties;
 use strict;
 use warnings;
 
-our $VERSION = '0.43';
+our $VERSION = '0.44';
 
 use IO::Handle;
 use Carp;
@@ -14,110 +14,111 @@ use Carp;
 #   which is an instance of Config::Properties to be used as defaults
 #   for this object.
 sub new {
-	my $proto = shift;
-	my $defaultProperties = shift;
-	my $perlMode = shift;
+    my $proto = shift;
+    my $defaultProperties = shift;
+    my $perlMode = shift;
 
-	my $class = ref($proto) || $proto;
-	my $self = {
-		'PERL_MODE' => (defined($perlMode) && $perlMode) ? 1 : 0,
+    ref($proto)
+	and carp "creating new Config::Properties objects from prototypes is deprecated";
+
+    my $class = ref($proto) || $proto;
+    my $self = {
+		'PERL_MODE' => $perlMode ? 1 : 0,
 		'defaults' => $defaultProperties,
 		'format' => '%s=%s',
-		'properties' => {}
-	};
-	bless($self, $class);
+		'properties' => {} };
+    bless $self, $class;
 
-	return $self;
+    $self->{PERL_MODE}
+	and carp "use of PerlMode flag is deprecated";
+
+    return $self;
 }
 
+
 #	setProperty() - Set the value for a specific property
 sub setProperty {
-	my $self = shift;
-	my $key = shift;
-	my $value = shift;
-	unless(defined($key) && length($key) && defined($value)) {
-	 croak "Config::Properties.setProperty( key, value )";
-	}
-	my $oldValue = $self->{'properties'}{ $key };
-	$self->{'properties'}{ $key } = $value;
-	return $oldValue;
+    my ($self, $key, $value)=@_;
+
+    defined($key) && length($key) && defined($value)
+	or croak "Config::Properties::setProperty( key, value )";
+
+    my $oldValue = $self->{properties}{ $key };
+    $self->{properties}{ $key } = $value;
+    return $oldValue;
 }
 
+
 #	getProperties() - Return a hashref of all of the properties
-sub getProperties {
-	my $self =  shift;
-	return $self->{'properties'};
-}
+sub getProperties { return { %{shift->{properties}} } }
+
+
+#	getFormat() - Return the output format for the properties
+sub getFormat { shift->{format} }
+
 
 #	setFormat() - Set the output format for the properties
 sub setFormat {
-	my $self = shift;
-	my $format = shift;
-	unless(defined($format) && length($format)) {
-		croak "Config::Properties.format( string )";
-	}
-	$self->{'format'} = $format;
+    my ($self, $format) = @_;
+
+    $self->{format} = defined($format) ? $format : '%s=%s';
 }
 
+
 #	format() - Alias for get/setFormat();
 sub format {
-	my $self = shift;
-	my $format = shift;
-	if (defined($format) && length($format)) {
-	 return $self->setFormat($format);
-	}
-	else {
-	 return $self->getFormat();
-	}
+    my $self = shift;
+    if (@_) {
+	return $self->setFormat(@_)
+    }
+    $self->getFormat();
 }
 
-#	getFormat() - Return the output format for the properties
-sub getFormat {
-	my $self = shift;
-	return $self->{'format'};
-}
 
 #       setValidator(\&validator) - Set sub to be called to validate
 #                property/value pairs.
 #                It is called &validator($property, $value, $config)
 #                being $config the Config::Properties object.
 sub setValidator {
-        my $self = shift;
-        my $validator = shift;
-	if (defined($validator) && !UNIVERSAL::isa($validator, 'CODE')) {
-	        croak "Config::Properties.setValidator( \&validator )"
-	}
-	$self->{validator} = $validator;
+    my ($self, $validator) = @_;
+
+    unless ( !defined($validator) or
+	     UNIVERSAL::isa($validator, 'CODE') ) {
+	croak "Config::Properties::setValidator( \&validator )"
+    }
+
+    $self->{validator} = $validator;
 }
 
+
 #       getValidator() - Return the current validator sub
-sub getValidator {
-        my $self=shift;
-	return $self->{validator}
-}
+sub getValidator { shift->{validator} }
+
 
 #       validator() - Alias for get/setValidator();
 sub validator {
-        my $self=shift;
-	if (@_) {
-	        return $self->{validator}=shift;
-	}
-	$self->{validator}
+    my $self=shift;
+    if (@_) {
+	return $self->setValidator(@_)
+    }
+    $self->getValidator
 }
 
+
 #	load() - Load the properties from a filehandle
 sub load {
-	my $self = shift;
-	my $file = shift;
-	unless(defined($file)) {
-		croak "Config::Properties.load( file )";
-	}
-	while (<$file>) {
-	        $self->{line_number}=$file->input_line_number;
-		$self->process_line($_, $file);
-	}
+    my ($self, $file) = @_;
+
+    defined($file)
+	or croak "Config::Properties::load( file )";
+
+    while (<$file>) {
+	$self->{line_number}=$file->input_line_number;
+	$self->process_line($_, $file);
+    }
 }
 
+
 #        escape_key(string), escape_value(string), unescape(string) -
 #               subroutines to convert escaped characters to their
 #               real counterparts back and forward.
@@ -144,50 +145,50 @@ sub unescape {
 	defined $1 ? $unesc{$1}||$1 : chr hex $2 /ge;
 }
 
+
 #	process_line() - Recursive function used to parse a line from the
 #					properties file.
 sub process_line {
-	my $self =  shift;
-	#print "XXX" . join("::", @_) . "XXX\n";
-	my $line = shift;
-	my $file = shift;
-	unless(defined($line) && defined($file)) {
-		croak "Config::Properties.process_line( line, file )";
-	}
-	chomp $line;
-	if ($line =~ /^\s*(\#|\!|$)/) {
-	 	return;
-	}
-	if ($line =~ /(\\+)$/ and length($1) % 2) {
-		$line =~ s/\\$//;
-		my $newline = <$file>;
-		$newline =~ s/^\s*//;
-		return $self->process_line($line . $newline, $file);
-	}
-	#print "XXX: " . $line . "\n";
-	my ($key, $value) = $line =~ /^
-				      \s*
-				      ((?:[^\s:=\\]|\\.)+)
-				      \s*
-				      [:=\s]
-				      \s*
-				      (.*)
-				      $
-				      /x
-	        or $self->fail("invalid property line '$line'");
+    my ($self, $line, $file) = @_;
+
+    # unless(defined($line) && defined($file)) {
+    # croak "Config::Properties::process_line( line, file )";
+    # }
+
+    chomp $line;
+    return if $line =~ /^\s*(\#|\!|$)/;
+
+    # handle continuation lines
+    my @lines;
+    while ($line =~ /(\\+)$/ and length($1) & 1) {
+	$line =~ s/\\$//;
+	push @lines, $line;
+	chomp($line = <$file>);
+	$line =~ s/^\s+//;
+    }
+    $line=join('', @lines, $line) if @lines;
+
+    my ($key, $value) = $line =~ /^
+				  \s*
+				  ((?:[^\s:=\\]|\\.)+)
+				  \s*
+				  [:=\s]
+				  \s*
+				  (.*)
+				  $
+				  /x
+       or $self->fail("invalid property line '$line'");
 	
-	unescape $key;
-	unescape $value;
-	$self->{properties}{$key} =
-	        $self->validate($key, $value);
+    unescape $key;
+    unescape $value;
+    $self->{properties}{$key} =
+	$self->validate($key, $value);
 }
 
 #       validate(key, value) - check if the property is valid.
 #               calls the validator if it has been set.
 sub validate {
-    my $self = shift;
-    my $key = shift;
-    my $value = shift;
+    my ($self, $key, $value)=@_;
     my $validator = $self->validator;
     if ($validator) {
 	return &{$validator}($key, $value, $self)
@@ -195,98 +196,102 @@ sub validate {
     $value;
 }
 
+
 #       line_number() - number for the last line read from the configuration file
-sub line_number {
-    my $self=shift;
-    return $self->{line_number}
-}
+sub line_number { shift->{line_number} }
+
 
 #       fail(error) - report errors in the configuration file while reading.
 sub fail {
-        my $self=shift;
-	my $error=shift;
-	die "$error at line ".$self->line_number()."\n";
+    my ($self, $error) = @_;
+    die "$error at line ".$self->line_number()."\n";
 }
 
 #	reallySave() - Utility function that performs the actual saving of
 #		the properties file to a filehandle.
 sub reallySave {
-	#print "XXX" . join("::", @_) . "XXX\n";
-	my $self = shift;
-	my $file = shift;
-	unless(defined($file)) {
-		croak "Config::Properties.reallySave( file )";
-	}
-	foreach (sort keys %{$self->{properties}}) {
-	        my ($key, $value)=($_, $self->{properties}{$_});
-		escape_key $key;
-		escape_value $value;
-		printf $file $self->{'format'} . "\n", $key, $value;
-	}
+    my ($self, $file) = @_;
+
+    defined($file)
+	or croak "Config::Properties::reallySave( file )";
+
+    foreach (sort keys %{$self->{properties}}) {
+	my $key=$_;
+	my $value=$self->{properties}{$key};
+	escape_key $key;
+	escape_value $value;
+	printf $file $self->{'format'} . "\n", $key, $value;
+    }
 }
 
+
 #	save() - Save the properties to a filehandle with the given header.
 sub save {
-	#print "XXX" . join("::", @_) . "XXX\n";
-	my $self = shift;
-	my $file = shift;
-	my $header = shift;
-	unless(defined($file) && defined($header) && length($header)) {
-	 croak "Config::Properties.save( file, header )";
-	}
-	print $file "#$header\n";
-	print $file '#' . localtime() . "\n";
-	$self->reallySave( $file );
+    my ($self, $file, $header)=@_;
+
+    defined $file
+	or croak "Config::Properties::save( file, header )";
+
+    if (defined $header) {
+	$header=~s/\n/# \n/sg;
+	print $file "# $header\n#\n";
+    }
+    print $file '# ' . localtime() . "\n\n";
+    $self->reallySave( $file );
 }
 
+
 #	store() - Synonym for save()
-sub store {
-	my $self = shift;
-	$self->save(@_);
-}
+sub store { shift->save(@_) }
+
 
 #	getProperty() - Return the value of a property key. Returns the default
 #		for that key (if there is one) if no value exists for that key.
 sub getProperty {
-	my $self = shift;
-	my $key = shift;
-	my $default = shift;
-	unless(defined($key) && length($key)) { # Key can be '0'!
-		croak "Config::Properties.getProperty( key )";
-	}
-	my $value = $self->{properties}{ $key };
-	if ($self->{defaults} && !defined($value)) { # Value can be '0' or empty string!
-	           $value = $self->{defaults}->getProperty($key);
-	}
-	return defined($value) ? $value : $default; # $value can be 0 or empty string if key exists!
+    my ($self, $key, $default)=@_;
+
+    defined($key) or
+	croak "Config::Properties::getProperty( key )";
+
+    if (exists $self->{properties}{$key}) {
+	return $self->{properties}{$key}
+    }
+    elsif (defined $self->{defaults}) {
+	return $self->{defaults}->getProperty($key, $default);
+    }
+    $default;
 }
 
+
 #	propertyName() - Returns an array of the keys of the Properties
-sub propertyNames {
-	my $self = shift;
-	return keys %{$self->{properties}};
+sub propertyNames { keys %{shift->{properties}};
 }
 
+
 #	list() - Same as store() except that it doesn't include a header.
 #		Meant for debugging use.
 sub list {
-	my $self = shift;
-	my $file = shift or croak "Config::Properties.list( file )";
-	print $file "-- listing properties --";
-	$self->reallySave( $file );
+    my ($self, $file) = @_;
+
+    defined $file
+	or croak "Config::Properties::list( file )";
+
+    print $file "# -- listing properties --";
+    $self->reallySave( $file );
 }
 
 #	setPerlMode() - Sets the value (true/false) of the PERL_MODE parameter.
 sub setPerlMode {
-	my $self = shift;	
-	my $mode = shift;
-	return $self->{'PERL_MODE'} = (defined($mode) && $mode) ? 1 : 0;
+    my ($self, $mode) = @_;
+    carp "use of PerlMode flag is deprecated";
+    return $self->{'PERL_MODE'} = (defined($mode) && $mode) ? 1 : 0;
 }
 
 #	perlMode() - Returns the current PERL_MODE setting (Default is false)
 sub perlMode {
-	my $self = shift;
-	return $self->{'PERL_MODE'};
+    my $self = shift;
+    carp "use of PerlMode flag is deprecated";
+    return $self->{'PERL_MODE'};
 }
 
 1;
@@ -338,6 +343,10 @@ printf control characters, but can be anything else. A newline will be automatic
 to the end of the string. You an get the current format string either by using
 $object->format() (with no arguments) or $object->getFormat().
 
+=over 4
+
+*** DEPRECATED ***
+
 If a true third parameter is passed to the constructor, the Config::Properties object
 be created in PERL_MODE. This can be set at any time by passing a true or false value
 into the setPerlMode() instance method. If in PERL_MODE, the behavior of the object
@@ -350,8 +359,16 @@ The following is a list of the current behavior changed under PERL_MODE:
 The current (true/false) value of PERL_MODE can be retrieved with the perlMode instance
 variable.
 
-=head1 AUTHOR
+--- As PERL_MODE has not ever done anything its usage has been deprecated ---
 
-C<Config::Properties> was developed by Randy Jay Yarger.
+*** DEPRECATED ***
+
+=back
+
+=head1 AUTHORS
+
+C<Config::Properties> was originally developed by Randy Jay Yarger. It
+was mantained for some time by Craig Manley and recently it has passed
+hands to Salvador Fandio <sfandino@yahoo.com>.
 
 =cut
